==> kubernetes-model-core-5.10.0-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ReplicationControllerStatusBuilder extends io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluentImpl<io.fabric8.kubernetes.api.model.ReplicationControllerStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ReplicationControllerStatus,io.fabric8.kubernetes.api.model.ReplicationControllerStatusBuilder>{
  public ReplicationControllerStatusBuilder() {
    this(false);
  }
  public ReplicationControllerStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new ReplicationControllerStatus(), validationEnabled);
  }
  public ReplicationControllerStatusBuilder(io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ReplicationControllerStatusBuilder(io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ReplicationControllerStatus(), validationEnabled);
  }
  public ReplicationControllerStatusBuilder(io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.ReplicationControllerStatus instance) {
    this(fluent, instance, false);
  }
  public ReplicationControllerStatusBuilder(io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.ReplicationControllerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailableReplicas(instance.getAvailableReplicas()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ReplicationControllerStatusBuilder(io.fabric8.kubernetes.api.model.ReplicationControllerStatus instance) {
    this(instance,false);
  }
  public ReplicationControllerStatusBuilder(io.fabric8.kubernetes.api.model.ReplicationControllerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailableReplicas(instance.getAvailableReplicas()); 
    this.withConditions(instance.getConditions()); 
    this.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withReplicas(instance.getReplicas()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ReplicationControllerStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ReplicationControllerStatus build() {
    ReplicationControllerStatus buildable = new ReplicationControllerStatus(fluent.getAvailableReplicas(),fluent.getConditions(),fluent.getFullyLabeledReplicas(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReplicationControllerStatusBuilder that = (ReplicationControllerStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/ReplicationControllerStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ReplicationControllerStatusBuilder extends ReplicationControllerStatusFluentImpl<ReplicationControllerStatusBuilder> implements VisitableBuilder<ReplicationControllerStatus,ReplicationControllerStatusBuilder>{
  public ReplicationControllerStatusBuilder() {
    this(false);
  }
  public ReplicationControllerStatusBuilder(Boolean validationEnabled) {
    this(new ReplicationControllerStatus(), validationEnabled);
  }
  public ReplicationControllerStatusBuilder(ReplicationControllerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ReplicationControllerStatusBuilder(ReplicationControllerStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ReplicationControllerStatus(), validationEnabled);
  }
  public ReplicationControllerStatusBuilder(ReplicationControllerStatusFluent<?> fluent,ReplicationControllerStatus instance) {
    this(fluent, instance, false);
  }
  public ReplicationControllerStatusBuilder(ReplicationControllerStatusFluent<?> fluent,ReplicationControllerStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailableReplicas(instance.getAvailableReplicas()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ReplicationControllerStatusBuilder(ReplicationControllerStatus instance) {
    this(instance,false);
  }
  public ReplicationControllerStatusBuilder(ReplicationControllerStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailableReplicas(instance.getAvailableReplicas()); 
    this.withConditions(instance.getConditions()); 
    this.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withReplicas(instance.getReplicas()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ReplicationControllerStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ReplicationControllerStatus build() {
    ReplicationControllerStatus buildable = new ReplicationControllerStatus(fluent.getAvailableReplicas(),fluent.getConditions(),fluent.getFullyLabeledReplicas(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
